@@ -1,5 +1,6 @@
 import datetime
 import json
+import sys
 import warnings
 from types import TracebackType
 from typing import (
@@ -15,6 +16,11 @@ from typing import (
 )
 from urllib.parse import urlparse
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
 import aiohttp
 from aiofile import AIOFile
 from aiohttp import FormData
@@ -507,11 +513,8 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
     async def create_segment(self, segment: Dict) -> StreamResponse:
         return await self.post("segments", data={"segment": segment})
 
-    async def get_segment(self, segment_id: str) -> StreamResponse:
-        return await self.get(f"segments/{segment_id}")
-
-    async def list_segments(self, **params: Any) -> StreamResponse:
-        return await self.get("segments", params)
+    async def query_segments(self, **params: Any) -> StreamResponse:
+        return await self.post("segments", data=params)
 
     async def update_segment(self, segment_id: str, data: Dict) -> StreamResponse:
         return await self.put(f"segments/{segment_id}", data={"segment": data})
@@ -522,11 +525,8 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
     async def create_campaign(self, campaign: Dict) -> StreamResponse:
         return await self.post("campaigns", data={"campaign": campaign})
 
-    async def get_campaign(self, campaign_id: str) -> StreamResponse:
-        return await self.get(f"campaigns/{campaign_id}")
-
-    async def list_campaigns(self, **params: Any) -> StreamResponse:
-        return await self.get("campaigns", params)
+    async def query_campaigns(self, **params: Any) -> StreamResponse:
+        return await self.post("campaigns", params)
 
     async def update_campaign(self, campaign_id: str, data: Dict) -> StreamResponse:
         return await self.put(f"campaigns/{campaign_id}", data={"campaign": data})
@@ -542,6 +542,9 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
             f"campaigns/{campaign_id}/schedule", data={"send_at": send_at}
         )
 
+    async def query_recipients(self, **params: Any) -> StreamResponse:
+        return await self.post("recipients", data=params)
+
     async def stop_campaign(self, campaign_id: str) -> StreamResponse:
         return await self.patch(f"campaigns/{campaign_id}/stop")
 
@@ -633,6 +636,20 @@ class StreamChatAsync(StreamChatInterface, AsyncContextManager):
     async def list_push_providers(self) -> StreamResponse:
         return await self.get("push_providers")
 
+    async def create_import_url(self, filename: str) -> StreamResponse:
+        return await self.post("import_urls", data={"filename": filename})
+
+    async def create_import(
+        self, path: str, mode: Literal["insert", "upsert"] = "upsert"
+    ) -> StreamResponse:
+        return await self.post("imports", data={"path": path, "mode": mode})
+
+    async def get_import(self, id: str) -> StreamResponse:
+        return await self.get(f"imports/{id}")
+
+    async def list_imports(self, options: Dict = None) -> StreamResponse:
+        return await self.get("imports", params=options)
+
     async def close(self) -> None:
         await self.session.close()
 
