@@ -4,8 +4,14 @@ import datetime
 import hashlib
 import hmac
 import os
+import sys
 from typing import Any, Awaitable, Dict, Iterable, List, TypeVar, Union
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
 import jwt
 
 from stream_chat.types.stream_response import StreamResponse
@@ -89,7 +95,9 @@ class StreamChatInterface(abc.ABC):
 
         return params
 
-    def verify_webhook(self, request_body: bytes, x_signature: str) -> bool:
+    def verify_webhook(
+        self, request_body: bytes, x_signature: Union[str, bytes]
+    ) -> bool:
         """
         Verify the signature added to a webhook event
 
@@ -97,6 +105,9 @@ class StreamChatInterface(abc.ABC):
         :param x_signature: the x-signature header included in the request
         :return: bool
         """
+        if isinstance(x_signature, bytes):
+            x_signature = x_signature.decode()
+
         signature = hmac.new(
             key=self.api_secret.encode(), msg=request_body, digestmod=hashlib.sha256
         ).hexdigest()
@@ -896,20 +907,11 @@ class StreamChatInterface(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def get_segment(
-        self, segment_id: str
-    ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
-        """
-        Get a segment by id
-        """
-        pass
-
-    @abc.abstractmethod
-    def list_segments(
+    def query_segments(
         self, **params: Any
     ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
         """
-        List segments
+        Query segments
         """
         pass
 
@@ -941,20 +943,11 @@ class StreamChatInterface(abc.ABC):
         pass
 
     @abc.abstractmethod
-    def get_campaign(
-        self, campaign_id: str
-    ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
-        """
-        Get a campaign by id
-        """
-        pass
-
-    @abc.abstractmethod
-    def list_campaigns(
+    def query_campaigns(
         self, **params: Any
     ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
         """
-        List campaigns
+        Query campaigns
         """
         pass
 
@@ -1012,6 +1005,15 @@ class StreamChatInterface(abc.ABC):
         """
         pass
 
+    @abc.abstractmethod
+    def query_recipients(
+        self, **params: Any
+    ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
+        """
+        Query recipients
+        """
+        pass
+
     @abc.abstractmethod
     def revoke_tokens(
         self, since: Union[str, datetime.datetime]
@@ -1117,6 +1119,89 @@ class StreamChatInterface(abc.ABC):
         """
         pass
 
+    @abc.abstractmethod
+    def create_import_url(
+        self, filename: str
+    ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
+        """
+        Create a URL to import a file.
+        Full flow:
+        ::
+
+            url_resp = client.create_import_url("myfile.json")
+
+            upload_resp = requests.put(
+                url_resp["upload_url"],
+                data=open("myfile.json", "rb"),
+                headers={"Content-Type": "application/json"},
+            )
+
+            create_resp = client.create_import(url_resp["path"], "upsert")
+            import_resp = client.get_import(create_resp["import_task"]["id"])
+        """
+        pass
+
+    def create_import(
+        self, path: str, mode: Literal["insert", "upsert"] = "upsert"
+    ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
+        """
+        Create an import task.
+        Full flow:
+        ::
+
+            url_resp = client.create_import_url("myfile.json")
+
+            upload_resp = requests.put(
+                url_resp["upload_url"],
+                data=open("myfile.json", "rb"),
+                headers={"Content-Type": "application/json"},
+            )
+
+            create_resp = client.create_import(url_resp["path"], "upsert")
+            import_resp = client.get_import(create_resp["import_task"]["id"])
+        """
+        pass
+
+    def get_import(self, id: str) -> Union[StreamResponse, Awaitable[StreamResponse]]:
+        """
+        Get the status of an import task.
+        Full flow:
+        ::
+
+            url_resp = client.create_import_url("myfile.json")
+
+            upload_resp = requests.put(
+                url_resp["upload_url"],
+                data=open("myfile.json", "rb"),
+                headers={"Content-Type": "application/json"},
+            )
+
+            create_resp = client.create_import(url_resp["path"], "upsert")
+            import_resp = client.get_import(create_resp["import_task"]["id"])
+        """
+        pass
+
+    def list_imports(
+        self, options: Dict = None
+    ) -> Union[StreamResponse, Awaitable[StreamResponse]]:
+        """
+        List all import tasks. Options can contain a "limit" and "offset" parameter.
+        Full flow:
+        ::
+
+            url_resp = client.create_import_url("myfile.json")
+
+            upload_resp = requests.put(
+                url_resp["upload_url"],
+                data=open("myfile.json", "rb"),
+                headers={"Content-Type": "application/json"},
+            )
+
+            create_resp = client.create_import(url_resp["path"], "upsert")
+            import_resp = client.get_import(create_resp["import_task"]["id"])
+        """
+        pass
+
     #####################
     #  Private methods  #
     #####################
