@@ -1,10 +1,17 @@
 import datetime
 import json
+import sys
 import warnings
 from typing import Any, Callable, Dict, Iterable, List, Union
 from urllib.parse import urlparse
 from urllib.request import Request, urlopen
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 import requests
 
 from stream_chat.__pkg__ import __version__
@@ -428,7 +435,7 @@ class StreamChat(StreamChatInterface):
             f"{self.base_url}/{uri}",
             params=self.get_default_params(),
             data={"user": json.dumps(user)},
-            files={"file": (name, content, content_type)},
+            files={"file": (name, content, content_type)},  # type: ignore
             headers=headers,
         )
         return self._parse_response(response)
@@ -484,11 +491,8 @@ class StreamChat(StreamChatInterface):
     def create_segment(self, segment: Dict) -> StreamResponse:
         return self.post("segments", data={"segment": segment})
 
-    def get_segment(self, segment_id: str) -> StreamResponse:
-        return self.get(f"segments/{segment_id}")
-
-    def list_segments(self, **params: Any) -> StreamResponse:
-        return self.get("segments", params)
+    def query_segments(self, **params: Any) -> StreamResponse:
+        return self.post("segments", data=params)
 
     def update_segment(self, segment_id: str, data: Dict) -> StreamResponse:
         return self.put(f"segments/{segment_id}", data={"segment": data})
@@ -499,11 +503,8 @@ class StreamChat(StreamChatInterface):
     def create_campaign(self, campaign: Dict) -> StreamResponse:
         return self.post("campaigns", data={"campaign": campaign})
 
-    def get_campaign(self, campaign_id: str) -> StreamResponse:
-        return self.get(f"campaigns/{campaign_id}")
-
-    def list_campaigns(self, **params: Any) -> StreamResponse:
-        return self.get("campaigns", params)
+    def query_campaigns(self, **params: Any) -> StreamResponse:
+        return self.post("campaigns", data=params)
 
     def update_campaign(self, campaign_id: str, data: Dict) -> StreamResponse:
         return self.put(f"campaigns/{campaign_id}", data={"campaign": data})
@@ -527,6 +528,9 @@ class StreamChat(StreamChatInterface):
     def test_campaign(self, campaign_id: str, users: Iterable[str]) -> StreamResponse:
         return self.post(f"campaigns/{campaign_id}/test", data={"users": users})
 
+    def query_recipients(self, **params: Any) -> StreamResponse:
+        return self.post("recipients", data=params)
+
     def revoke_tokens(self, since: Union[str, datetime.datetime]) -> StreamResponse:
         if isinstance(since, datetime.datetime):
             since = since.isoformat()
@@ -598,3 +602,17 @@ class StreamChat(StreamChatInterface):
 
     def list_push_providers(self) -> StreamResponse:
         return self.get("push_providers")
+
+    def create_import_url(self, filename: str) -> StreamResponse:
+        return self.post("import_urls", data={"filename": filename})
+
+    def create_import(
+        self, path: str, mode: Literal["insert", "upsert"] = "upsert"
+    ) -> StreamResponse:
+        return self.post("imports", data={"path": path, "mode": mode})
+
+    def get_import(self, id: str) -> StreamResponse:
+        return self.get(f"imports/{id}")
+
+    def list_imports(self, options: Dict = None) -> StreamResponse:
+        return self.get("imports", params=options)
